# Equitrac::Utilities

[![Build Status](https://travis-ci.org/LAS-IT/equitrac-utilities.svg?branch=master)](https://travis-ci.org/LAS-IT/equitrac-utilities)  [![Dependency Status](https://beta.gemnasium.com/badges/github.com/LAS-IT/equitrac-utilities.svg)](https://beta.gemnasium.com/projects/github.com/LAS-IT/equitrac-utilities)  [![Codacy Badge](https://api.codacy.com/project/badge/Grade/3d1bbe096fe34e3c8785cd6fb2af103c)](https://www.codacy.com/app/btihen/equitrac-utilities?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=LAS-IT/equitrac-utilities&amp;utm_campaign=Badge_Grade)  [![Codacy Badge](https://api.codacy.com/project/badge/Coverage/3d1bbe096fe34e3c8785cd6fb2af103c)](https://www.codacy.com/app/btihen/equitrac-utilities?utm_source=github.com&utm_medium=referral&utm_content=LAS-IT/equitrac-utilities&utm_campaign=Badge_Coverage)  [![BCH compliance](https://bettercodehub.com/edge/badge/LAS-IT/equitrac-utilities?branch=master)](https://bettercodehub.com/)

Equitrac utilities help you run any EQCmd command within ruby. It use SSH by default so make sure you windows server is setup for ssh.

## CHANGE LOG

* 0.2.0 - not compatible with 0.1.0
  - rename Server Class to Connection Class be consistent a with a suite of account management gems

* 0.1.0 - initial gem

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'equitrac-utilities'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install equitrac-utilities

## Usage

### Initialize server object

```ruby
require 'equitrac-utilities'

# With variables
server = Equitrac::Connection.new "host.exemple.com", "admin", "server-name", "password"

# OR with environment variables

ENV['EQUITRAC_HOST'] = "host.exemple.com"
ENV['EQUITRAC_USER'] = "admin"
ENV['EQUITRAC_SERVICE_NAME'] = "server-name"
ENV['EQUITRAC_HOST_PASSWORD'] = "password"

server = Equitrac::Connection.new
```

if you want to use key based authentication just ignore the password.

### Generate add user command

```ruby

min_user_params = {
  user_id: "jdoe",
  init_bal: 50.0,
  user_name: "John DOE",
  email: "jdoe@exemple.com",
  dept_name: "employee",
  primary_pin: 0420,
}

cmd = Equitrac::Utilities::User.add( min_user_params )

```

### Execute command

```ruby
  # with key authentication do:

  # server object = Equitrac::Connection.new "host.exemple.com", "admin", "server-name"
  server.execute(cmd)

  # if the password is define in the object, it will be included automatically into the options.
  # server object = Equitrac::Connection.new "host.exemple.com", "admin", "server-name", "password"
  server.execute(cmd, {verify_host_key: false})
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake test` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Test

using:
```
rake test TEST=test/equitrac/*
```

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/las-it/equitrac-utilities.

Pull requests need tests.

## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

All rights on Equitrac are owned by [Nuance Communications, Inc.](https://www.nuance.com/index.html)
